You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@myfaces.apache.org by lo...@apache.org on 2015/07/01 15:42:06 UTC

svn commit: r1688651 - in /myfaces/tobago/branches/tobago-3.0.x: ./ tobago-core/src/main/java/org/apache/myfaces/tobago/component/ tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/ tobago-core/src/main/java/org/apache/myfaces/tobago/interna...

Author: lofwyr
Date: Wed Jul  1 13:42:05 2015
New Revision: 1688651

URL: http://svn.apache.org/r1688651
Log:
TOBAGO-1435: New Layout: SegmentLayout which uses 12 columns (like Bootstrap)
- Renaming tc:columnLayout to tc:segmentLayout, because there is a column layout in CSS. See: http://www.w3.org/TR/css3-multicol/

Added:
    myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/SegmentLayoutRule.java
      - copied, changed from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/ColumnLayoutRule.java
    myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUISegmentLayout.java
      - copied, changed from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIColumnLayout.java
    myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/SegmentLayoutTagDeclaration.java
      - copied, changed from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/ColumnLayoutTagDeclaration.java
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/
      - copied from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/bootstrapLayout/
    myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/SegmentLayoutRenderer.java
      - copied, changed from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/ColumnLayoutRenderer.java
Removed:
    myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/ColumnLayoutRule.java
    myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIColumnLayout.java
    myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/ColumnLayoutTagDeclaration.java
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/bootstrapLayout/
    myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/ColumnLayoutRenderer.java
Modified:
    myfaces/tobago/branches/tobago-3.0.x/tobago-3.0.txt
    myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/component/RendererTypes.java
    myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/TobagoComponentHandler.java
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/editor.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/layout/basic.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/tab/personal.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/in/in.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1-as-facet.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2-as-facet.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3-as-facet.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3.xhtml
    myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/PanelRenderer.java

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-3.0.txt
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-3.0.txt?rev=1688651&r1=1688650&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-3.0.txt (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-3.0.txt Wed Jul  1 13:42:05 2015
@@ -17,13 +17,13 @@ Todo:
 
   - consolidate LinkRenderer, ButtonRenderer with CommandRenderer
 
-  - simplify: layout without facet and container (columnLayout, ...):
+  - simplify: layout without facet and container (gridLayout, ... any other?):
 
 Done:
 
   - Removing tc:cell tag, please use tc:panel instead.
 
-  - simplify (flowLayout, flexLayout):
+  - simplify (flowLayout, flexLayout, segmentLayout):
 
     <tc:flowLayout>
       ... content ...

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/component/RendererTypes.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/component/RendererTypes.java?rev=1688651&r1=1688650&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/component/RendererTypes.java (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/component/RendererTypes.java Wed Jul  1 13:42:05 2015
@@ -31,7 +31,7 @@ public final class RendererTypes {
   @Deprecated
   public static final String CELL = "Cell";
   public static final String COLUMN = "Column";
-  public static final String COLUMN_LAYOUT = "ColumnLayout";
+  public static final String SEGMENT_LAYOUT = "SegmentLayout";
   public static final String COLUMN_SELECTOR = "ColumnSelector";
   public static final String COMMAND = "Command";
   public static final String COMMAND_GROUP = "CommandGroup";

Copied: myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/SegmentLayoutRule.java (from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/ColumnLayoutRule.java)
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/SegmentLayoutRule.java?p2=myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/SegmentLayoutRule.java&p1=myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/ColumnLayoutRule.java&r1=1688582&r2=1688651&rev=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/ColumnLayoutRule.java (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/SegmentLayoutRule.java Wed Jul  1 13:42:05 2015
@@ -20,7 +20,7 @@
 package org.apache.myfaces.tobago.facelets;
 
 import org.apache.myfaces.tobago.component.Attributes;
-import org.apache.myfaces.tobago.component.UIColumnLayout;
+import org.apache.myfaces.tobago.component.UISegmentLayout;
 import org.apache.myfaces.tobago.layout.ColumnPartition;
 
 import javax.faces.view.facelets.FaceletContext;
@@ -29,12 +29,12 @@ import javax.faces.view.facelets.Metadat
 import javax.faces.view.facelets.MetadataTarget;
 import javax.faces.view.facelets.TagAttribute;
 
-public class ColumnLayoutRule extends MetaRule {
+public class SegmentLayoutRule extends MetaRule {
 
-  public static final ColumnLayoutRule INSTANCE = new ColumnLayoutRule();
+  public static final SegmentLayoutRule INSTANCE = new SegmentLayoutRule();
 
   public Metadata applyRule(final String name, final TagAttribute attribute, final MetadataTarget metadataTarget) {
-    if (metadataTarget.isTargetInstanceOf(UIColumnLayout.class)) {
+    if (metadataTarget.isTargetInstanceOf(UISegmentLayout.class)) {
       if (attribute.isLiteral()) {
         if (Attributes.EXTRA_SMALL.equals(name)) {
           return new ExtraSmallMapper(attribute);
@@ -61,7 +61,7 @@ public class ColumnLayoutRule extends Me
     }
 
     public void applyMetadata(final FaceletContext ctx, final Object instance) {
-      final UIColumnLayout gridLayout = (UIColumnLayout) instance;
+      final UISegmentLayout gridLayout = (UISegmentLayout) instance;
       gridLayout.setExtraSmall(ColumnPartition.valueOf(attribute.getValue()));
     }
   }
@@ -74,7 +74,7 @@ public class ColumnLayoutRule extends Me
     }
 
     public void applyMetadata(final FaceletContext ctx, final Object instance) {
-      final UIColumnLayout gridLayout = (UIColumnLayout) instance;
+      final UISegmentLayout gridLayout = (UISegmentLayout) instance;
       gridLayout.setSmall(ColumnPartition.valueOf(attribute.getValue()));
     }
   }
@@ -87,7 +87,7 @@ public class ColumnLayoutRule extends Me
     }
 
     public void applyMetadata(final FaceletContext ctx, final Object instance) {
-      final UIColumnLayout gridLayout = (UIColumnLayout) instance;
+      final UISegmentLayout gridLayout = (UISegmentLayout) instance;
       gridLayout.setMedium(ColumnPartition.valueOf(attribute.getValue()));
     }
   }
@@ -100,7 +100,7 @@ public class ColumnLayoutRule extends Me
     }
 
     public void applyMetadata(final FaceletContext ctx, final Object instance) {
-      final UIColumnLayout gridLayout = (UIColumnLayout) instance;
+      final UISegmentLayout gridLayout = (UISegmentLayout) instance;
       gridLayout.setLarge(ColumnPartition.valueOf(attribute.getValue()));
     }
   }

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/TobagoComponentHandler.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/TobagoComponentHandler.java?rev=1688651&r1=1688650&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/TobagoComponentHandler.java (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/facelets/TobagoComponentHandler.java Wed Jul  1 13:42:05 2015
@@ -30,7 +30,7 @@ import org.apache.myfaces.tobago.config.
 import org.apache.myfaces.tobago.event.SheetStateChangeSource;
 import org.apache.myfaces.tobago.event.SortActionSource;
 import org.apache.myfaces.tobago.event.TabChangeSource;
-import org.apache.myfaces.tobago.internal.component.AbstractUIColumnLayout;
+import org.apache.myfaces.tobago.internal.component.AbstractUISegmentLayout;
 import org.apache.myfaces.tobago.internal.component.AbstractUIFlowLayout;
 import org.apache.myfaces.tobago.internal.component.AbstractUIGridLayout;
 import org.apache.myfaces.tobago.internal.component.AbstractUIPopup;
@@ -72,8 +72,8 @@ public class TobagoComponentHandler exte
     if (AbstractUIFlowLayout.class.isAssignableFrom(aClass)) {
       metaRuleset.addRule(FlowLayoutRule.INSTANCE);
     }
-    if (AbstractUIColumnLayout.class.isAssignableFrom(aClass)) {
-      metaRuleset.addRule(ColumnLayoutRule.INSTANCE);
+    if (AbstractUISegmentLayout.class.isAssignableFrom(aClass)) {
+      metaRuleset.addRule(SegmentLayoutRule.INSTANCE);
     }
     if (TabChangeSource.class.isAssignableFrom(aClass)) {
       metaRuleset.addRule(TabChangeSourceRule.INSTANCE);

Copied: myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUISegmentLayout.java (from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIColumnLayout.java)
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUISegmentLayout.java?p2=myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUISegmentLayout.java&p1=myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIColumnLayout.java&r1=1688582&r2=1688651&rev=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUIColumnLayout.java (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/component/AbstractUISegmentLayout.java Wed Jul  1 13:42:05 2015
@@ -27,7 +27,7 @@ import org.apache.myfaces.tobago.layout.
  * TODO
  * @since 3.0.0
  */
-public abstract class AbstractUIColumnLayout extends AbstractUILayoutBase implements LayoutManager, SupportsMarkup {
+public abstract class AbstractUISegmentLayout extends AbstractUILayoutBase implements LayoutManager, SupportsMarkup {
 
   public static final String COMPONENT_FAMILY = "org.apache.myfaces.tobago.BootstrapLayout";
 

Copied: myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/SegmentLayoutTagDeclaration.java (from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/ColumnLayoutTagDeclaration.java)
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/SegmentLayoutTagDeclaration.java?p2=myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/SegmentLayoutTagDeclaration.java&p1=myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/ColumnLayoutTagDeclaration.java&r1=1688582&r2=1688651&rev=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/ColumnLayoutTagDeclaration.java (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/taglib/component/SegmentLayoutTagDeclaration.java Wed Jul  1 13:42:05 2015
@@ -24,7 +24,7 @@ import org.apache.myfaces.tobago.apt.ann
 import org.apache.myfaces.tobago.apt.annotation.UIComponentTag;
 import org.apache.myfaces.tobago.apt.annotation.UIComponentTagAttribute;
 import org.apache.myfaces.tobago.component.RendererTypes;
-import org.apache.myfaces.tobago.internal.component.AbstractUIColumnLayout;
+import org.apache.myfaces.tobago.internal.component.AbstractUISegmentLayout;
 import org.apache.myfaces.tobago.internal.taglib.declaration.HasBinding;
 import org.apache.myfaces.tobago.internal.taglib.declaration.HasCurrentMarkup;
 import org.apache.myfaces.tobago.internal.taglib.declaration.HasId;
@@ -34,15 +34,15 @@ import org.apache.myfaces.tobago.interna
  * Renders a layout using a 12 columns grid.
  * @since 3.0.0
  */
-@Tag(name = "columnLayout")
+@Tag(name = "segmentLayout")
 @UIComponentTag(
-    uiComponent = "org.apache.myfaces.tobago.component.UIColumnLayout",
-    uiComponentBaseClass = "org.apache.myfaces.tobago.internal.component.AbstractUIColumnLayout",
+    uiComponent = "org.apache.myfaces.tobago.component.UISegmentLayout",
+    uiComponentBaseClass = "org.apache.myfaces.tobago.internal.component.AbstractUISegmentLayout",
     uiComponentFacesClass = "javax.faces.component.UIComponentBase",
-    componentFamily = AbstractUIColumnLayout.COMPONENT_FAMILY,
-    rendererType = RendererTypes.COLUMN_LAYOUT,
+    componentFamily = AbstractUISegmentLayout.COMPONENT_FAMILY,
+    rendererType = RendererTypes.SEGMENT_LAYOUT,
     allowedChildComponenents = "NONE", isLayout = true)
-public interface ColumnLayoutTagDeclaration extends HasId, HasBinding, HasMarkup, HasCurrentMarkup {
+public interface SegmentLayoutTagDeclaration extends HasId, HasBinding, HasMarkup, HasCurrentMarkup {
 
   /**
    * TODO

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/editor.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/editor.xhtml?rev=1688651&r1=1688650&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/editor.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/editor.xhtml Wed Jul  1 13:42:05 2015
@@ -60,7 +60,7 @@
 
         <tc:panel>
           <f:facet name="layout">
-            <tc:columnLayout medium="2;10"/>
+            <tc:segmentLayout medium="2;10"/>
           </f:facet>
 
           <tc:out/>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/layout/basic.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/layout/basic.xhtml?rev=1688651&r1=1688650&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/layout/basic.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/layout/basic.xhtml Wed Jul  1 13:42:05 2015
@@ -81,7 +81,7 @@
 
         <tc:panel>
           <f:facet name="layout">
-            <tc:columnLayout medium="2;3;1;2;3;1"/>
+            <tc:segmentLayout medium="2;3;1;2;3;1"/>
           </f:facet>
           <!--
                 <tc:form>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/tab/personal.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/tab/personal.xhtml?rev=1688651&r1=1688650&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/tab/personal.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-addressbook/src/main/webapp/addressbook/tab/personal.xhtml Wed Jul  1 13:42:05 2015
@@ -26,7 +26,7 @@
   <tc:flowLayout>
     <tc:panel>
         <f:facet name="layout">
-          <tc:columnLayout medium="2;10"/>
+          <tc:segmentLayout medium="2;10"/>
         </f:facet>
 
         <tx:in value="#{controller.currentAddress.firstName}"
@@ -40,7 +40,7 @@
 
         <tc:panel>
           <f:facet name="layout">
-            <tc:columnLayout medium="2;8;2"/>
+            <tc:segmentLayout medium="2;8;2"/>
           </f:facet>
           <tx:in value="#{controller.currentAddress.street}"
                  label="#{bundle.editorStreet}"/>
@@ -49,7 +49,7 @@
 
         <tc:panel>
           <f:facet name="layout">
-            <tc:columnLayout medium="2;3;7"/>
+            <tc:segmentLayout medium="2;3;7"/>
           </f:facet>
           <tx:in value="#{controller.currentAddress.zipCode}"
                  label="#{bundle.editorCity}"/>
@@ -58,7 +58,7 @@
 
     <tc:panel>
       <f:facet name="layout">
-        <tc:columnLayout medium="2;10"/>
+        <tc:segmentLayout medium="2;10"/>
       </f:facet>
 
         <tx:selectOneChoice

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/in/in.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/in/in.xhtml?rev=1688651&r1=1688650&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/in/in.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/in/in.xhtml Wed Jul  1 13:42:05 2015
@@ -23,7 +23,7 @@
 
   <tc:page>
 
-    <tc:columnLayout large="8;4">
+    <tc:segmentLayout large="8;4">
 
 
       <tc:in label="First Value" value="#{in.first}"/>
@@ -32,7 +32,7 @@
 
       <tc:button label="submit"/>
 
-    </tc:columnLayout>
+    </tc:segmentLayout>
 
   </tc:page>
 </f:view>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1-as-facet.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1-as-facet.xhtml?rev=1688651&r1=1688582&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1-as-facet.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1-as-facet.xhtml Wed Jul  1 13:42:05 2015
@@ -24,7 +24,7 @@
   <tc:page id="page" label="Layout (old)">
 
     <f:facet name="layout">
-      <tc:columnLayout medium="2;4;2;4" small="6;6"/>
+      <tc:segmentLayout medium="2;4;2;4" small="6;6"/>
     </f:facet>
 
     <tx:in label="1st label" value="a aa aaa aaaa aaaaa"/>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1.xhtml?rev=1688651&r1=1688582&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-1.xhtml Wed Jul  1 13:42:05 2015
@@ -22,11 +22,11 @@
     xmlns:f="http://java.sun.com/jsf/core">
 
   <tc:page id="page" label="Layout">
-    <tc:columnLayout medium="2;4;2;4" small="6;6">
+    <tc:segmentLayout medium="2;4;2;4" small="6;6">
       <tx:in label="1st label" value="a aa aaa aaaa aaaaa"/>
       <tx:in label="2nd label" value="b bb bbb bbbb bbbbb b bb bbb bbbb bbbbb b bb bbb bbbb bbb bbbb bbbbb "/>
       <tx:textarea label="3rd label" value="c cc ccc cccc ccccc"/>
       <tx:textarea label="4th label" value="d dd ddd dddd ddddd"/>
-    </tc:columnLayout>
+    </tc:segmentLayout>
   </tc:page>
 </f:view>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2-as-facet.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2-as-facet.xhtml?rev=1688651&r1=1688582&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2-as-facet.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2-as-facet.xhtml Wed Jul  1 13:42:05 2015
@@ -28,7 +28,7 @@
   <tc:page id="page">
     <tc:panel>
       <f:facet name="layout">
-        <tc:columnLayout medium="2;4;2;4" small="6;6"/>
+        <tc:segmentLayout medium="2;4;2;4" small="6;6"/>
       </f:facet>
 
       <tx:in label="1st label" value="a aa aaa aaaa aaaaa"/>
@@ -36,7 +36,7 @@
     </tc:panel>
     <tc:panel>
       <f:facet name="layout">
-        <tc:columnLayout medium="2;4;2;4" small="6;6"/>
+        <tc:segmentLayout medium="2;4;2;4" small="6;6"/>
       </f:facet>
 
       <tx:textarea label="3rd label" value="c cc ccc cccc ccccc"/>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2.xhtml?rev=1688651&r1=1688582&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-2.xhtml Wed Jul  1 13:42:05 2015
@@ -26,13 +26,13 @@
   -->
 
   <tc:page id="page">
-    <tc:columnLayout medium="2;4;2;4" small="6;6">
+    <tc:segmentLayout medium="2;4;2;4" small="6;6">
       <tx:in label="1st label" value="a aa aaa aaaa aaaaa"/>
       <tx:in label="2nd label" value="b bb bbb bbbb bbbbb b bb bbb bbbb bbbbb b bb bbb bbbb bbb bbbb bbbbb "/>
-    </tc:columnLayout>
-    <tc:columnLayout medium="2;4;2;4" small="6;6">
+    </tc:segmentLayout>
+    <tc:segmentLayout medium="2;4;2;4" small="6;6">
       <tx:textarea label="3rd label" value="c cc ccc cccc ccccc"/>
       <tx:textarea label="4th label" value="d dd ddd dddd ddddd"/>
-    </tc:columnLayout>
+    </tc:segmentLayout>
   </tc:page>
 </f:view>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3-as-facet.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3-as-facet.xhtml?rev=1688651&r1=1688582&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3-as-facet.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3-as-facet.xhtml Wed Jul  1 13:42:05 2015
@@ -24,7 +24,7 @@
   <tc:page id="page">
     <tc:panel>
       <f:facet name="layout">
-        <tc:columnLayout medium="2;4;2;4" small="6;6"/>
+        <tc:segmentLayout medium="2;4;2;4" small="6;6"/>
       </f:facet>
 
       <tx:in label="1st label" value="#{bootstrap.value}"/>
@@ -32,7 +32,7 @@
     </tc:panel>
     <tc:panel>
       <f:facet name="layout">
-        <tc:columnLayout medium="2;4;2;4" small="6;6"/>
+        <tc:segmentLayout medium="2;4;2;4" small="6;6"/>
       </f:facet>
 
       <tx:textarea label="3rd label" value="c cc ccc cccc ccccc"/>
@@ -41,7 +41,7 @@
     </tc:panel>
     <tc:panel>
       <f:facet name="layout">
-        <tc:columnLayout medium="1;1;1" extraSmall="4;4;4"/>
+        <tc:segmentLayout medium="1;1;1" extraSmall="4;4;4"/>
       </f:facet>
 
       <tc:button id="cancel" label="Cancel" action="#{bootstrap.reset}"/>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3.xhtml
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3.xhtml?rev=1688651&r1=1688582&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3.xhtml (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-example/tobago-example-test/src/main/webapp/test/segmentLayout/simple-3.xhtml Wed Jul  1 13:42:05 2015
@@ -23,21 +23,21 @@
 
   <tc:page id="page">
 
-    <tc:columnLayout medium="2;4;2;4" small="6;6">
+    <tc:segmentLayout medium="2;4;2;4" small="6;6">
       <tx:in label="1st label" value="#{bootstrap.value}"/>
       <tx:in label="2nd label" value="b bb bbb bbbb bbbbb b bb bbb bbbb bbbbb b bb bbb bbbb bbb bbbb bbbbb "/>
-    </tc:columnLayout>
+    </tc:segmentLayout>
 
-    <tc:columnLayout medium="2;4;2;4" small="6;6">
+    <tc:segmentLayout medium="2;4;2;4" small="6;6">
       <tx:textarea label="3rd label" value="c cc ccc cccc ccccc"/>
       <tx:textarea label="4th label" value="d dd ddd dddd ddddd"/>
-    </tc:columnLayout>
+    </tc:segmentLayout>
 
-    <tc:columnLayout medium="1;1;1" extraSmall="4;4;4">
+    <tc:segmentLayout medium="1;1;1" extraSmall="4;4;4">
       <tc:button id="cancel" label="Cancel" action="#{bootstrap.reset}"/>
       <tc:button id="save" label="Save" action="#{bootstrap.save}"/>
       <tc:button id="delete" label="Delete" action="#{bootstrap.delete}"/>
-    </tc:columnLayout>
+    </tc:segmentLayout>
 
   </tc:page>
 </f:view>

Modified: myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/PanelRenderer.java
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/PanelRenderer.java?rev=1688651&r1=1688650&r2=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/PanelRenderer.java (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/PanelRenderer.java Wed Jul  1 13:42:05 2015
@@ -22,7 +22,7 @@ package org.apache.myfaces.tobago.render
 import org.apache.myfaces.tobago.component.Facets;
 import org.apache.myfaces.tobago.component.UIPanel;
 import org.apache.myfaces.tobago.component.UIReload;
-import org.apache.myfaces.tobago.internal.component.AbstractUIColumnLayout;
+import org.apache.myfaces.tobago.internal.component.AbstractUISegmentLayout;
 import org.apache.myfaces.tobago.internal.component.AbstractUIPanel;
 import org.apache.myfaces.tobago.internal.util.FacesContextUtils;
 import org.apache.myfaces.tobago.layout.Measure;
@@ -70,7 +70,7 @@ public class PanelRenderer extends Layou
     writer.startElement(HtmlElements.DIV, panel);
     writer.writeIdAttribute(clientId);
 
-    if (panel.getLayoutManager() instanceof AbstractUIColumnLayout) {
+    if (panel.getLayoutManager() instanceof AbstractUISegmentLayout) {
       // TBD: this might be nicer, wen using the layout not as a facet
       writer.writeClassAttribute(Classes.create(panel), BootstrapClass.ROW);
     } else {

Copied: myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/SegmentLayoutRenderer.java (from r1688582, myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/ColumnLayoutRenderer.java)
URL: http://svn.apache.org/viewvc/myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/SegmentLayoutRenderer.java?p2=myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/SegmentLayoutRenderer.java&p1=myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/ColumnLayoutRenderer.java&r1=1688582&r2=1688651&rev=1688651&view=diff
==============================================================================
--- myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/ColumnLayoutRenderer.java (original)
+++ myfaces/tobago/branches/tobago-3.0.x/tobago-theme/tobago-theme-standard/src/main/java/org/apache/myfaces/tobago/renderkit/html/standard/standard/tag/SegmentLayoutRenderer.java Wed Jul  1 13:42:05 2015
@@ -20,10 +20,10 @@
 package org.apache.myfaces.tobago.renderkit.html.standard.standard.tag;
 
 import org.apache.myfaces.tobago.component.Facets;
-import org.apache.myfaces.tobago.component.UIColumnLayout;
+import org.apache.myfaces.tobago.component.UISegmentLayout;
 import org.apache.myfaces.tobago.component.UIExtensionPanel;
 import org.apache.myfaces.tobago.component.UILabel;
-import org.apache.myfaces.tobago.internal.component.AbstractUIColumnLayout;
+import org.apache.myfaces.tobago.internal.component.AbstractUISegmentLayout;
 import org.apache.myfaces.tobago.layout.LayoutContainer;
 import org.apache.myfaces.tobago.renderkit.RendererBase;
 import org.apache.myfaces.tobago.renderkit.css.Css;
@@ -44,9 +44,9 @@ import java.util.List;
 /**
  * Renders the 12 columns layout.
  */
-public class ColumnLayoutRenderer extends RendererBase {
+public class SegmentLayoutRenderer extends RendererBase {
 
-  private static final Logger LOG = LoggerFactory.getLogger(ColumnLayoutRenderer.class);
+  private static final Logger LOG = LoggerFactory.getLogger(SegmentLayoutRenderer.class);
 
   @Override
   public boolean getRendersChildren() {
@@ -55,10 +55,10 @@ public class ColumnLayoutRenderer extend
 
   @Override
   public void encodeBegin(final FacesContext facesContext, final UIComponent component) throws IOException {
-    final AbstractUIColumnLayout columnLayout = (AbstractUIColumnLayout) component;
+    final AbstractUISegmentLayout segmentLayout = (AbstractUISegmentLayout) component;
     final TobagoResponseWriter writer = HtmlRendererUtils.getTobagoResponseWriter(facesContext);
 
-    writer.startElement(HtmlElements.DIV, columnLayout);
+    writer.startElement(HtmlElements.DIV, segmentLayout);
 //    writer.writeClassAttribute("row");
 //    writer.writeClassAttribute(BootstrapClass.FORM_HORIZONTAL, BootstrapClass.CONTAINER_FLUID);
     writer.writeClassAttribute(BootstrapClass.FORM_GROUP);
@@ -68,15 +68,15 @@ public class ColumnLayoutRenderer extend
   @Override
   public void encodeChildren(final FacesContext facesContext, final UIComponent component) throws IOException {
     final TobagoResponseWriter writer = HtmlRendererUtils.getTobagoResponseWriter(facesContext);
-    final UIColumnLayout columnLayout = (UIColumnLayout) component;
+    final UISegmentLayout segmentLayout = (UISegmentLayout) component;
 
-    UIComponent container = columnLayout.getParent();
-    if (container.getFacet(Facets.LAYOUT) == columnLayout) {
+    UIComponent container = segmentLayout.getParent();
+    if (container.getFacet(Facets.LAYOUT) == segmentLayout) {
       // case (old style): layout manager over facet
       LOG.warn("Using this layout via a facet is deprecated. Please put the layout around the components.");
     } else {
-      // case (modern style): the columnLayout contains the content to be layed out.
-      container = columnLayout;
+      // case (modern style): the segmentLayout contains the content to be layed out.
+      container = segmentLayout;
     }
 
     if (container instanceof LayoutContainer && !((LayoutContainer) container).isLayoutChildren()) {
@@ -85,10 +85,10 @@ public class ColumnLayoutRenderer extend
 
     final List<UIComponent> children = container.getChildren();
     final BootstrapCssGenerator generator = new BootstrapCssGenerator(
-        columnLayout.getExtraSmall(),
-        columnLayout.getSmall(),
-        columnLayout.getMedium(),
-        columnLayout.getLarge());
+        segmentLayout.getExtraSmall(),
+        segmentLayout.getSmall(),
+        segmentLayout.getMedium(),
+        segmentLayout.getLarge());
     for (UIComponent child : children) {
       if (child.isRendered()) {
         if (child instanceof UIExtensionPanel) {